translate.services.tmserver

Package translate :: Package services :: Module tmserver |
[hide private]
[frames] | no frames]

# Module tmserver

source code

A translation memory server using tmdb for storage, communicates with clients using JSON over HTTP.

Classes | [hide private]
| TMServer A RESTful JSON TM server.

Functions | [hide private]
main() | source code

Variables | [hide private]
| __package__ = ``'``translate.services``'``

Imports: logging, parse_qs, OptionParser, json, selector, wsgi, base, tmdb